==> jc-1.4.0.tar.gz: soot/baf/internal/BGotoInst.h <==
// public class soot.baf.internal.BGotoInst

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cabcce676e3c10e6 soot_baf_internal_AbstractBranchInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class d3de1e4bf89ffae4 soot_baf_internal_BGotoInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractBranchInst

#include "soot/baf/internal/AbstractBranchInst.h"

#ifndef _JC_soot_baf_internal_BGotoInst_H_
#define _JC_soot_baf_internal_BGotoInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Unit$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BGotoInst$sub_refs	_jc_soot_baf_internal_BGotoInst$sub_refs;
typedef struct _jc_soot_baf_internal_BGotoInst$sub_nonrefs	_jc_soot_baf_internal_BGotoInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BGotoInst$refs	_jc_soot_baf_internal_BGotoInst$refs;
typedef struct _jc_soot_baf_internal_BGotoInst$nonrefs	_jc_soot_baf_internal_BGotoInst$nonrefs;
typedef struct _jc_soot_baf_internal_BGotoInst$object	_jc_soot_baf_internal_BGotoInst$object;

typedef const struct _jc_soot_baf_internal_BGotoInst$vmethods	_jc_soot_baf_internal_BGotoInst$vmethods;
typedef const struct _jc_soot_baf_internal_BGotoInst$vtable	_jc_soot_baf_internal_BGotoInst$vtable;
typedef const struct _jc_soot_baf_internal_BGotoInst$vtype	_jc_soot_baf_internal_BGotoInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BGotoInst$method$_init$9fbfbaac54ec3a82(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_baf_internal_BGotoInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *, struct _jc_object *);
extern jboolean _jc_soot_baf_internal_BGotoInst$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BGotoInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
extern jboolean _jc_soot_baf_internal_BGotoInst$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
extern jint _jc_soot_baf_internal_BGotoInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
extern jint _jc_soot_baf_internal_BGotoInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BGotoInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
extern jint _jc_soot_baf_internal_BGotoInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
extern jint _jc_soot_baf_internal_BGotoInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BGotoInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *, struct _jc_object *);
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *);
};

// Vtable
struct _jc_soot_baf_internal_BGotoInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractBranchInst$vmethods	soot_baf_internal_AbstractBranchInst;
	_jc_soot_baf_internal_BGotoInst$vmethods	soot_baf_internal_BGotoInst;
};

// Vtype
struct _jc_soot_baf_internal_BGotoInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BGotoInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BGotoInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BGotoInst$refs {
    _jc_soot_baf_internal_BGotoInst$sub_refs	soot_baf_internal_BGotoInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_refs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BGotoInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BGotoInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_BGotoInst$sub_nonrefs	soot_baf_internal_BGotoInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BGotoInst$object {
	_jc_soot_baf_internal_BGotoInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BGotoInst$vtype	*vtype;
	_jc_soot_baf_internal_BGotoInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BGotoInst$vtype _jc_soot_baf_internal_BGotoInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BGotoInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BGotoInst$class_object;

#endif	/* _JC_soot_baf_internal_BGotoInst_H_ */

==> jc-1.4.6.tar.gz: soot/baf/internal/BGotoInst.h <==
// public class soot.baf.internal.BGotoInst

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cabcce676e3c10e6 soot_baf_internal_AbstractBranchInst
// @dep_class 75a736fe6c448796 soot_baf_internal_AbstractInst
// @dep_class d3de1e4bf89ffae4 soot_baf_internal_BGotoInst
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_baf_internal_AbstractBranchInst

#include "soot/baf/internal/AbstractBranchInst.h"

#ifndef _JC_soot_baf_internal_BGotoInst_H_
#define _JC_soot_baf_internal_BGotoInst_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Unit$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_baf_internal_BGotoInst$sub_refs	_jc_soot_baf_internal_BGotoInst$sub_refs;
typedef struct _jc_soot_baf_internal_BGotoInst$sub_nonrefs	_jc_soot_baf_internal_BGotoInst$sub_nonrefs;
typedef struct _jc_soot_baf_internal_BGotoInst$refs	_jc_soot_baf_internal_BGotoInst$refs;
typedef struct _jc_soot_baf_internal_BGotoInst$nonrefs	_jc_soot_baf_internal_BGotoInst$nonrefs;
typedef struct _jc_soot_baf_internal_BGotoInst$object	_jc_soot_baf_internal_BGotoInst$object;

typedef const struct _jc_soot_baf_internal_BGotoInst$vmethods	_jc_soot_baf_internal_BGotoInst$vmethods;
typedef const struct _jc_soot_baf_internal_BGotoInst$vtable	_jc_soot_baf_internal_BGotoInst$vtable;
typedef const struct _jc_soot_baf_internal_BGotoInst$vtype	_jc_soot_baf_internal_BGotoInst$vtype;

// Constructors
extern void _jc_soot_baf_internal_BGotoInst$method$_init$9fbfbaac54ec3a82(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_baf_internal_BGotoInst$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_baf_internal_BGotoInst$method$branches$b1fa209d4c0e0b15(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_baf_internal_BGotoInst$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_baf_internal_BGotoInst$method$fallsThrough$09e8b0d6b0c9d1bf(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BGotoInst$method$getInCount$56a53206ce41ebab(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BGotoInst$method$getInMachineCount$53f8938c85f21ad5(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_baf_internal_BGotoInst$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BGotoInst$method$getOutCount$de2aea04cd3e0d65(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_internal_BGotoInst$method$getOutMachineCount$382bb5439d011100(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$branches$b1fa209d4c0e0b15;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$fallsThrough$09e8b0d6b0c9d1bf;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getInCount$56a53206ce41ebab;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getInMachineCount$53f8938c85f21ad5;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getOutCount$de2aea04cd3e0d65;
extern _jc_method _jc_soot_baf_internal_BGotoInst$method_info$getOutMachineCount$382bb5439d011100;

// Virtual methods structure
struct _jc_soot_baf_internal_BGotoInst$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*branches$b1fa209d4c0e0b15)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
	jboolean	(*fallsThrough$09e8b0d6b0c9d1bf)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
	jint	(*getInCount$56a53206ce41ebab)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
	jint	(*getInMachineCount$53f8938c85f21ad5)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutCount$de2aea04cd3e0d65)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
	jint	(*getOutMachineCount$382bb5439d011100)(_jc_env *, struct _jc_soot_baf_internal_BGotoInst$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_internal_BGotoInst$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_baf_internal_AbstractInst$vmethods	soot_baf_internal_AbstractInst;
	_jc_soot_baf_internal_AbstractBranchInst$vmethods	soot_baf_internal_AbstractBranchInst;
	_jc_soot_baf_internal_BGotoInst$vmethods	soot_baf_internal_BGotoInst;
};

// Vtype
struct _jc_soot_baf_internal_BGotoInst$vtype {
	_jc_type			type;
	_jc_soot_baf_internal_BGotoInst$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_internal_BGotoInst$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_baf_internal_BGotoInst$refs {
    _jc_soot_baf_internal_BGotoInst$sub_refs	soot_baf_internal_BGotoInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_refs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_AbstractInst$sub_refs	soot_baf_internal_AbstractInst;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_internal_BGotoInst$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_baf_internal_BGotoInst$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_baf_internal_AbstractInst$sub_nonrefs	soot_baf_internal_AbstractInst;
    _jc_soot_baf_internal_AbstractBranchInst$sub_nonrefs	soot_baf_internal_AbstractBranchInst;
    _jc_soot_baf_internal_BGotoInst$sub_nonrefs	soot_baf_internal_BGotoInst;
};

// Object instance structure
struct _jc_soot_baf_internal_BGotoInst$object {
	_jc_soot_baf_internal_BGotoInst$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_internal_BGotoInst$vtype	*vtype;
	_jc_soot_baf_internal_BGotoInst$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_internal_BGotoInst$vtype _jc_soot_baf_internal_BGotoInst$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_internal_BGotoInst, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_internal_BGotoInst$class_object;

#endif	/* _JC_soot_baf_internal_BGotoInst_H_ */
